@@ -15,7 +15,7 @@ found=0
 XmHFound=0
 XmLibFound=0
 
-if uname | grep Linux 2>/dev/null
+if uname | grep Linux > /dev/null 2>&1
 then
    # declare the possible pathes for include files
    InclPathes='/usr/X11R6/include
@@ -38,13 +38,13 @@ then
       then
          CMD='cat /etc/ld.so.conf'
       else
-         CMD='cat /etc/ld.so.conf.d/*.conf /etc/ld.so.conf | grep -v include'
+         CMD='cat /etc/ld.so.conf.d/*.conf /etc/ld.so.conf'
       fi
    else
       CMD='cat /etc/ld.so.conf'
    fi
 
-   for l in `$CMD` $LibPathes
+   for l in `$CMD | grep -v include` $LibPathes
    do
       # and for each of the possible location for the motif headers
       for XmHPath in $InclPathes
