@@ -60,6 +60,7 @@
 #include "cfg2.h"
 #include "wheelmouse.h"
 #include "micon.h"
+#include "access.h"
 
 #include "rdPrtDesc.h"
 #define defaultConfigData configData
@@ -282,7 +283,7 @@ static void cfgNext_CB(Widget w, XtPointer clientData, XtPointer callData)
 /* show if the device files stated in the global device list       */
 /* are present and if we have read and write right to them.        */
 /* If all is OK insert them in the list deviceName                 */
-/*                                                                 */  
+/*                                                                 */
 /* Output: char  **deviceName                                      */
 /*                                                                 */
 /* return: number of device file found                             */
@@ -293,9 +294,6 @@ static int readDevDir(char **deviceName)
 {
    int i;
    int count = 0;
-   struct stat status;
-   int euid = geteuid();
-   int egid = getegid();
    DIR *dir;
    struct dirent *ent;
    char *fname = NULL;
@@ -303,80 +301,24 @@ static int readDevDir(char **deviceName)
    for (i = 0;  deviceList[i] != NULL; i++)
    {
       /* acess as group or user */
-      if (access(deviceList[i],  R_OK|W_OK) == 0 )
+      if (fileAccess(deviceList[i], R_OK|W_OK) == 0 )
       {
          deviceName[count++] = strdup(deviceList[i]);
       }
-      else
-      {
-         if ( stat(deviceList[i],&status) == 0 )
-         {
-            /* access as root */
-            if ((euid==0  && (status.st_mode & (S_IRUSR|S_IWUSR))==(S_IRUSR|S_IWUSR)))
-            {
-               deviceName[count++] = strdup(deviceList[i]);
-            }
-            else
-            {
-               /* access as an other priviliged user */
-               if ( status.st_uid == euid )
-               {
-                  deviceName[count++] = strdup(deviceList[i]);
-               }
-               else
-               {
-                  /* privilged group ? */
-                  if ( status.st_gid == egid && (status.st_mode & (S_IRGRP|S_IWGRP)) == (S_IRGRP|S_IWGRP))
-                  {
-                     deviceName[count++] = strdup(deviceList[i]);
-                  }
-               }
-            }
-         }
-      }
    }
- 
    /* add entries found under /var/mtink */
    if ( (dir = opendir("/var/mtink")) )
    {
-     while ( (ent = readdir(dir)) != NULL )
+      while ( (ent = readdir(dir)) != NULL )
       {
          if ( ent->d_name[0] == '.' )
             continue;
          fname = (char*)calloc(strlen("/var/mtink/")+ strlen(ent->d_name)+1,1);    
          sprintf(fname, "/var/mtink/%s", ent->d_name);
-         if (access(fname,  W_OK) == 0 )
+         if (fileAccess(fname,  W_OK) == 0 )
          {
             deviceName[count++] = strdup(fname);
          }
-         else
-         {
-            if ( stat(fname,&status) == 0 )
-            {
-               /* access as root */
-               if ((euid==0  && (status.st_mode & (S_IRUSR|S_IWUSR))==(S_IRUSR|S_IWUSR)))
-               {
-                  deviceName[count++] = strdup(fname);
-               }
-               else
-               {
-                  /* access as an other proviliged user */
-                  if ( status.st_uid == euid )
-                  {
-                     deviceName[count++] = strdup(fname);
-                  }
-                  else
-                  {
-                     /* privilged group ? */
-                     if ( status.st_gid == egid && (status.st_mode & (S_IRGRP|S_IWGRP)) == (S_IRGRP|S_IWGRP))
-                     {
-                        deviceName[count++] = strdup(fname);
-                     }
-                  }
-               }
-            }
-         }
-         free(fname);
       }
       closedir(dir);
    }
