@@ -20,6 +20,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <ctype.h>
  
 /* List of environment variables we accept */
 static char *envVars[] =
@@ -183,9 +184,6 @@ int checkEnv(char **env)
    char *m;
    char *u;
    char **envName = NULL;
-   int   len = 0;
-   char *name = NULL;
-   int   nameSize;
 
    /* check the environment variable against the allowed */
    /* variable, if the variable is not into our array of */
