@@ -27,6 +27,7 @@
 #include <string.h>
 #include <signal.h>
 #include <unistd.h>
+#include <ctype.h>
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/wait.h>
@@ -87,6 +88,8 @@ static unsigned char printer_cmd[65536]; /* more as enough now */
 static int  bufpos = 0;
 int doRw = 0;
 
+extern int inFromFile;
+
 extern void setPrinterStateLabel(int state);
 
 /* module global variables */
@@ -150,8 +153,6 @@ static void waitForPrinterReady(int deviceHdl, int maxWaitTime);
 
 int writeD4Data(int deviceHdl, unsigned char *printer_cmd, int len, int stop);
 
-static void _sigAlarm(int code);
-
 #define CMD_IDX          4
 #define AllInkPosition   1
 #define BlackInkPosition 3
@@ -174,7 +175,7 @@ static unsigned char carriagePosition[] = {
    pass this 5 sec after issuing the xi command
  */
 
-#if 0
+#if 0 /* not used yet */
 #define ReplyExchangePossibility 0
 #define ReplyCatridgeState       1
 static unsigned char CartridgeState[] = {
@@ -189,7 +190,7 @@ static unsigned char exchangeInkTerminate[] = {
 };
 
 
-static int _Write(int a, char *b, int c, int to)
+static int _Write(int a, unsigned char *b, int c, int to)
 {
    int i;
    if ( debugD4 )
@@ -210,7 +211,7 @@ static int _Write(int a, char *b, int c, int to)
 #endif
 }
 
-static int _Read(int a,  char *b, int c, int to)
+static int _Read(int a, unsigned char *b, int c, int to)
 {
    int i;
 #ifndef MACOS
@@ -218,6 +219,9 @@ static int _Read(int a,  char *b, int c, int to)
 # else
    int ret = mRead(a,b,c);
 #endif
+if ( inFromFile )
+return 0;
+
    if ( ret > 0 && debugD4 )
    {
       fprintf(stderr, "Read : ");
@@ -292,9 +296,7 @@ static void parentDie(int code)
  ******************************************************/
  
 void *doCommands(void *dummy)
-{
-    int count = 0; /* limit the time for the loop */
-  
+{  
 #if WITH_X
     if ( display )
     {
@@ -534,7 +536,7 @@ int callPrg(int command, char *name, int mode, int pass, int choice, char **retB
 #ifdef MACOS
       if ( strncmp(name,USB_PRT_NAME_PREFIX,strlen(USB_PRT_NAME_PREFIX)) )
 #else
-      if ( strncmp(name, "/dev/", 5) )
+      if ( strncmp(name, "/dev/", 5) && !inFromFile)
 #endif
       {
         /* server must be running */
@@ -631,7 +633,7 @@ int callPrg(int command, char *name, int mode, int pass, int choice, char **retB
          else
          {
 #if DEBUG
-            perror("shmget");
+            perror("shmget private memory");
 #endif
          }
       }
@@ -1164,27 +1166,6 @@ void setPrinterName(char *name)
 }
 #endif
 
-static struct  itimerval ti, oti;
-typedef void (*signalHandler_t)(int);
-static signalHandler_t sig;
-
-/******************************************************
- * Function: _sigAlarm()
- *
- * This signal handler is necessary in order to
- * catch timeout events for file operations 
- * 
- ******************************************************/
-
-static void _sigAlarm(int code)
-{
-#if DEBUG
-   fprintf(stderr,"_sigAlarm got\n");
-#endif
-#ifdef linux
-   doRw = 0;
-#endif
-}
 #if 1
 #ifdef MACOS
 #define RESET_TIMER(ti,oti) { signal(SIGALRM, sig); \
@@ -1270,12 +1251,12 @@ static int openAndTestDevice(char *dev )
       d4RdTimeout = 200;
       for(i = 1; i > 0;)
       {
-         i = _Read(deviceHdl, iBuf, 511, 500);
+         i = _Read(deviceHdl, (uc*)iBuf, 511, 500);
       }
       d4RdTimeout = oldTimeOut;
    }
 
-   len = _Write(deviceHdl, "\033\1@EJL ID\r\n",11, 500);
+   len = _Write(deviceHdl, (uc*)"\033\1@EJL ID\r\n",11, 500);
    if ( len != 11 )
    {
 #if DEBUG
@@ -1295,7 +1276,7 @@ static int openAndTestDevice(char *dev )
       fprintf(stderr,"read from %s\n",dev);
 #endif
 
-      len = _Read(deviceHdl, shmem->buf, 511, 500);
+      len = _Read(deviceHdl, (uc*)shmem->buf, 511, 500);
       if ( len > 0 )
          break;
       usleep(50000);
@@ -1343,11 +1324,11 @@ static int openDevice(char *dev, int doTest )
    int oldTimeOut;
    char iBuf[512];
 #if DEBUG
-   fprintf(stderr,"openDevice(%s, %d)\n",dev, doTest);
+   fprintf(stderr,"+++ Enter openDevice(%s, %d)\n",dev, doTest);
 #endif
+
    if ( deviceHdl == -1 && doTest )
    {
-
       i = openAndTestDevice(dev);
       if ( i == 2 )
       {
@@ -1395,6 +1376,13 @@ static int openDevice(char *dev, int doTest )
 #if DEBUG
          fprintf(stderr,"%s opened (%d)\n",dev, deviceHdl);
 #endif
+         if ( inFromFile ) /* Test: we read from a file, don't read anythings */
+         {
+#if DEBUG
+            fprintf(stderr,"openDevice() done, not Flush\n");
+#endif
+            return deviceHdl;
+         }
       }
       /* flush the printer output buffer */
 #if DEBUG
@@ -1404,7 +1392,7 @@ static int openDevice(char *dev, int doTest )
       d4RdTimeout = 200;
       for(i = 1; i > 0;)
       {
-         i = _Read(deviceHdl, (char*)iBuf, 511, 500);
+         i = _Read(deviceHdl, (uc*)iBuf, 511, 500);
       }
       d4RdTimeout = oldTimeOut;
    }
@@ -1439,7 +1427,7 @@ static int exitD4(int deviceHdl)
       CloseChannel(deviceHdl,sockId);
    sockIdData = sockId = -1;
 
-   len = _Write(deviceHdl, "\0\0\0\033\1@EJL 1284.4\n@EJL     \n", 27, 500);
+   len = _Write(deviceHdl, (uc*)"\0\0\0\033\1@EJL 1284.4\n@EJL     \n", 27, 500);
    if ( len != 27 )
    {
       /* write failed */
@@ -1448,7 +1436,7 @@ static int exitD4(int deviceHdl)
    /* we have to wait a little bit */
    usleep(100000);
 
-   len = _Read(deviceHdl, shmem->buf, 511, 1000);
+   len = _Read(deviceHdl, (uc*)shmem->buf, 511, 1000);
    if ( len == -1 )
    {
       /* no information available */
@@ -1518,7 +1506,9 @@ static int getId(char *name, int prot)
             if ( initializeD4() )
             {
                if ( i > 0 )
+               {
                   return 1;
+               }
             }
             else
             {
@@ -1545,10 +1535,11 @@ static int getIq(char *name, int prot)
 {
 #if TEST
 #if TEST_DEBUG
-printf("Call getIqD4()\n");
+printf("Call getIqD4(%s, %d)\n".name,prot);
 #endif
 return getIqD4(deviceHdl);
 #endif
+
    /* This may be the first call from mtink, no autodetection */
    /* if the printer is a D4 model and the ink is low we will */
    /* block the printer if we query for identification with   */
@@ -1781,14 +1772,24 @@ int initializeD4()
          break;
    }
 
-   /* flush */
-   oldTimeOut = d4RdTimeout;
-   d4RdTimeout = 200;
-   for (i=1;i>0;)
+   if ( !inFromFile )
    {
-      i = readData(deviceHdl,sockId, (uc*)iBuf, 511);
+      /* flush */
+      oldTimeOut = d4RdTimeout;
+      d4RdTimeout = 200;
+      for (i=1;i>0;)
+      {
+         i = readData(deviceHdl,sockId, (uc*)iBuf, 511);
+         if ( !inFromFile ) break;
+      }
+      d4RdTimeout = oldTimeOut;
+   }
+   else
+   {
+      /* read the next answer (credit) which what issued bey the */
+      /* above call of readData() in normal mode                 */
+      devRead(deviceHdl, (uc*)iBuf, 511, 0);
    }
-   d4RdTimeout = oldTimeOut;
    d4Initialized = True;
 
    return 0;
@@ -1810,7 +1811,7 @@ static int getIdNoD4(int deviceHdl, int prot)
    if ( (prot & PROT_EXIT) )
       exitD4(deviceHdl);
 
-   len = _Write(deviceHdl, "\033\1@EJL ID\r\n", 11, 500);
+   len = _Write(deviceHdl, (uc*)"\033\1@EJL ID\r\n", 11, 500);
    if ( len != 11 )
    {
 #if DEBUG
@@ -1824,7 +1825,7 @@ static int getIdNoD4(int deviceHdl, int prot)
    /* arm a timer so we will not block */
    for ( i = 0; i < 5; i++ )
    {
-      len = _Read(deviceHdl, shmem->buf, 511, WRTIMEOUT);
+      len = _Read(deviceHdl, (uc*)shmem->buf, 511, WRTIMEOUT);
       if ( len > 0 )
          break;
       usleep(100000);
@@ -1859,7 +1860,7 @@ static int getIqOld(int deviceHdl, int prot)
       exitD4(deviceHdl);
    }
 
-   len = _Write(deviceHdl, "\033@\033@\033(R\010\0\0REMOTE1IQ\1\0\1\033\0\0\0", 26, 500);
+   len = _Write(deviceHdl, (uc*)"\033@\033@\033(R\010\0\0REMOTE1IQ\1\0\1\033\0\0\0", 26, 500);
    if ( len != 26 )
    {
       return 1;
@@ -1870,7 +1871,7 @@ static int getIqOld(int deviceHdl, int prot)
 
    for ( i = 0; i < 5; i++ )
    {
-      len = _Read(deviceHdl, shmem->buf, 511, 500);
+      len = _Read(deviceHdl,(uc*) shmem->buf, 511, 500);
       if ( len > 0 )
          break;
       usleep(1000000);
@@ -1907,7 +1908,7 @@ static int resetPrinterOld(int deviceHdl, int prot)
 
    if ( !(prot & PROT_D4) )
    {
-      len = _Write(deviceHdl, (char*)resetCommand, resetCommandLen, 500);
+      len = _Write(deviceHdl, resetCommand, resetCommandLen, 500);
       if ( len != 26 )
       {
          return 1;
@@ -1947,7 +1948,7 @@ static int checkNozzleOld(int deviceHdl, int prot)
       exitD4(deviceHdl);
 
    len = _Write(deviceHdl,
-                "\033@\033@\033(R\010\0\0REMOTE1NC\2\0\0\0\033\0\0\0\f", 28, 500);
+             (uc*)"\033@\033@\033(R\010\0\0REMOTE1NC\2\0\0\0\033\0\0\0\f", 28, 500);
    if ( len != 28 )
    {
       return 1;
@@ -1974,7 +1975,7 @@ static int cleanNozzleOld(int deviceHdl, int prot)
    if  ( (prot & PROT_EXIT)  )
       exitD4(deviceHdl);
 
-   len = _Write(deviceHdl, "\033@\033@\033(R\010\0\0REMOTE1CH\2\0\0\0\033\0\0\0", 27, 500);
+   len = _Write(deviceHdl, (uc*)"\033@\033@\033(R\010\0\0REMOTE1CH\2\0\0\0\033\0\0\0", 27, 500);
    if ( len != 27 )
    {
       return 1;
@@ -2037,7 +2038,7 @@ readAgain:
    {
       ret = 1;
    }
- 
+
    return ret;
 }
 
@@ -2062,6 +2063,7 @@ char getColorModel(char *s, int count)
    int B = 0;
    int X = 0;
    int k = 0;
+   int g = 0;
 
    int idx;
    for ( idx = 0; idx < count; idx++ )
@@ -2074,6 +2076,7 @@ char getColorModel(char *s, int count)
                  case 3:  k++; break;
                  case 4:  k++; break;
                  case 5:  k++; break;
+                 case 12: g++; break;
                  default: K++; break;
              }
           break;
@@ -2087,10 +2090,13 @@ char getColorModel(char *s, int count)
           case  9: R++; break;
           case 10: B++; break;
           case 11: X++; break;
+          case 12: g++; break;
        }
        s += 3;
    }
+
    if ( R && B && X && k ) return MODEL_KCMyRBkX;
+   else if ( g && k ) return MODEL_KCMycmGg;
    else if ( R && B && X ) return MODEL_KCMyRBX;
    else if ( R && B ) return MODEL_KCMyRB;
    else if ( Y )      return MODEL_KCMycmY;
@@ -2160,6 +2166,7 @@ char getColorModel(char *s, int count)
  *      0x09 Red
  *      0x0a Blue
  *      0x0b Clear
+ *      0x0c light light black (Photo R2400)
  *
  *    The different Black are recognised according to there position
  *    eg;
@@ -2169,7 +2176,7 @@ char getColorModel(char *s, int count)
  *
  ******************************************************/
 
-convertToAsciiSt(char *buf, int len)
+void convertToAsciiSt(char *buf, int len)
 {
     unsigned char tmp[1024];
     int  i;
@@ -2178,17 +2185,18 @@ convertToAsciiSt(char *buf, int len)
     int  val[8];
     char *s = buf+7;
     char colorModel;
-    int K = 0;
-    int C = 0;
-    int M = 0;
-    int y = 0;
-    int c = 0;
-    int m = 0;
-    int Y = 0;
-    int R = 0;
-    int B = 0;
-    int X = 0;
-    int k = 0;
+    int K = 0;  /* Black */
+    int C = 0;  /* Cyan  */
+    int M = 0;  /* Magenta */
+    int y = 0;  /* light yellow */
+    int c = 0;  /* light cyan */
+    int m = 0;  /* light magenta */
+    int Y = 0;  /* Yellow */
+    int R = 0;  /* Red */
+    int B = 0;  /* Blue */
+    int X = 0;  /* Gloss */
+    int k = 0;  /* matte/light grey */
+    int g = 0;  /* light light grey */
 
     /* save the data to a temporary buffer so we can */
     /* modify the input buffer                       */
@@ -2216,7 +2224,7 @@ printf("Tag = %02x length %d\n", (unsigned char)tmp[i],tmp[i+1]);
           case 15: /* ink quantity */
              sprintf(s, "INQ:");
              s += 4;
-             cnt = tmp[i+1] / 3;       
+             cnt = tmp[i+1] / 3;
 #if TEST_DEBUG
 printf("%d inks\n",cnt);
 #endif
@@ -2229,16 +2237,17 @@ printf("%d inks model %c\n",cnt,*s);
              /* make shure that color order is OK */
              /* MODELS ARE: KCMy      '1'    colorcode 0123
                             KCMycm    '2'              012345
-                            KCMycmY   '3'              012346
+                            KCMycmY   '3'              0123456
                             KCMycmk   '4'              01239A
                             KCMyRB    '5'              01239AB
                             KCMyRBX   '6'              01239ABX
                             KCMyRBkX  '7'              01239AB0X
+                            KCMycmGg  '8'              012359Ag
              */
              for ( j = 0; j < cnt; j++ )
              {
 #if TEST_DEBUG
-printf("Color code st pos %d = %d\n",j,tmp[i+4+(3*j)]);
+printf("Color code st pos %d = %d val=%d\n",j,tmp[i+4+(3*j)], tmp[i+5+(3*j)]);
 #endif
                 switch(tmp[i+4+(3*j)])
                 {
@@ -2248,8 +2257,9 @@ printf("Color code st pos %d = %d\n",j,tmp[i+4+(3*j)]);
                       {
                          K = (unsigned char)tmp[i+5+(3*j)];
                       }
-                      else if ( j == 4 ) /* photo black on R800 */
-                      {
+                      else if ( j == 4 && colorModel != MODEL_KCMycmGg )
+                      {                    /* black on R2400     */
+                         /* photo black on R800 */
                          k = (unsigned char)tmp[i+5+(3*j)];
                       }
                       else
@@ -2276,6 +2286,7 @@ printf("Color code st pos %d = %d\n",j,tmp[i+4+(3*j)]);
                        Y = tmp[i+5+(3*j)];
                    break;
                    case  7: /* grey        at pos 6 */
+                   case  8: /* grey        at pos 3 */
                        k = (unsigned char)(unsigned char)tmp[i+5+(3*j)];
                    break;
                    case  9: /* red         at pos 4 */
@@ -2287,6 +2298,9 @@ printf("Color code st pos %d = %d\n",j,tmp[i+4+(3*j)]);
                    case 11: /* gloss       at pos 6 or 7 */
                        X = (unsigned char)tmp[i+5+(3*j)];
                    break;
+                   case 12: /*ligth light black pos 0 */
+                       g = (unsigned char)tmp[i+5+(3*j)];
+                   break;
                 }
              }
 
@@ -2344,6 +2358,15 @@ printf("Color code st pos %d = %d\n",j,tmp[i+4+(3*j)]);
                    sprintf(s, "%02x", k); s += 2;
                    sprintf(s, "%02x", X); s += 2;
                 break;
+                case MODEL_KCMycmGg:
+                   sprintf(s, "%02x", K); s += 2;
+                   sprintf(s, "%02x", C); s += 2;
+                   sprintf(s, "%02x", M); s += 2;
+                   sprintf(s, "%02x", y); s += 2;
+                   sprintf(s, "%02x", c); s += 2;
+                   sprintf(s, "%02x", m); s += 2;
+                   sprintf(s, "%02x", k); s += 2;
+                   sprintf(s, "%02x", g); s += 2;
                 case MODEL_KCMy:
                 default:
                    sprintf(s, "%02x", K); s += 2;
@@ -2377,103 +2400,7 @@ static int getIqD4(int deviceHdl)
    int i;
    int ret = 1;
    shmem->buf[0] = '\0';
-#if 0
-{
-   unsigned char *s = shmem->buf;
-   *s++ = '@';  // 0
-   *s++ = 'B';
-   *s++ = 'D';
-   *s++ = 'C';
-   *s++ = ' ';
-   *s++ = 'S';
-   *s++ = 'T';
-   *s++ = '2';  // 7
-   *s++ = 0x0d;
-   *s++ = 0x0a;
-   *s++ = 0x21; // 10
-   *s++ = 0;
-   *s++ = 1;    // 12  ST
-   *s++ = 1;    //     length
-   *s++ = 4;     // st = OK
-   *s++ = 0x0b;  // 15
-   *s++ = 5;
-   *s++ = 2;
-   *s++ = 0;
-   *s++ = 0;
-   *s++ = 0;
-   *s++ = 0;
 
-   *s++ = 0x0f;  // 22 // IC
-   *s++ = 13+6+3;  // length
-   *s++ = 3;     // 
-
-   *s++ = 1;
-   *s++ = 0;     // black
-   *s++ = 0x38;  // value
-
-   *s++ = 3;
-   *s++ = 1;     // Cyan
-   *s++ = 0x40;  // value
-
-   *s++ = 4;
-   *s++ = 2;     // Magenta
-   *s++ = 0x40;  // value
-
-   *s++ = 5;
-   *s++ = 3;     // Yelow
-   *s++ = 0x41;  // value
-
-   *s++ = 3;
-   *s++ = 0x09;
-   *s++ = 0x50;
-
-   *s++ = 3;
-   *s++ = 0x0a;
-   *s++ = 0x50;
-
-   *s++ = 3;
-   *s++ = 0x0b;
-   *s++ = 0x30;
-
-   *s++ = 0x10;   
-   *s++ = 1;
-   *s++ = 1;
-   i = s - shmem->buf;
-   goto test;
-}
-#endif
-#if 0 /* Stylus Photo R200 */
-/*
-   char hex[] = "40 42 44 43 20 53 54 32 0d 0a 2c 00 01 01 04 0b 07 "
-   "03 34 33 36 30 30 2f 0f 13 03 01 00 0c 03 01 63 06 04 16 04 02 "
-   "5d 07 05 59 05 03 5d 10 06 01 0a 4e 08 4e 4e 13 01 01\0\0\0";
-*/
-   /* Stylus Photo R800 */
-   char hex[] = "40 42 44 43 20 53 54 32 0d 0a 5e 00 01 01 00 02 01 05 06 02 01 ff 0b 11 04 2f 31 32 34 31 30 32 36 2e 2d 34 35 34 31 31 36 0e 01 09 0f 19 03 05 03 00 04 02 55 03 01 3c 0b 00 60 01 00 5e 0c 09 10 0d 0a 0a 0e 0b 51 10 09 01 08 4e 0e 4e 4e 01 4e 4e 13 01 01 15 02 2e 00 19 0c 00 00 00 00 00 75 6e 6b 6e 6f 77 6e 1b 01 dd "
-
-/*"40 42 44 43 20 53 54 32 0d 0a 5b 00 01 01 04 04 01 14 06 02 01 ff 0b 11 04 34 32 2f 37 30 30 32 34 36 35 "
-             "32 38 2b 30 2f 32 0f 19 03 05 03 25 04 02 52 03 01 1c 0b 00 2c 01 00 05 0c 09 54 0d 0a 0a 0e 0b 60 10 09 01 "*/
-           /*                         -- ----C-VV ----C-VV ----C-VV ----C-VV ----C-VV ----C-VV ----C-VV ----C-VV */
-           /*                          1  2  3  4  5  6  7  8  9  a  b  c  d  e  f 10 11 12 13 14 15 16 17 18 19 */
-           /*                                Y 37     M 82     C 28     K 44     k  5     R 84     B 38     X 96 */
-             "08 4e 0e 4e 4e 01 4e 4e 13 01 01 15 02 30 00 19 0c 00 00 00 00 00 75 6e 6b 6e 6f 77 6e 1b 01 "
-             "00""""""""";
-
-   unsigned char *t = shmem->buf;
-   unsigned char *s = hex;
-
-   while(*s)
-   {
-      sscanf(s, "%x",&i);
-      *t = i&0xff;
-      s +=3;
-      t++;
-      *t = '\0';
-   }
-   i = (int)t - (int)shmem->buf;
-
-   goto test;
-#endif
 
    credit = askForCredit(deviceHdl, sockId, &sndSize, &rcvSize);
    if ( credit > -1 )
@@ -2484,7 +2411,6 @@ static int getIqD4(int deviceHdl)
 readAgain:
          if ( ( i = readData(deviceHdl, sockId, (uc*)shmem->buf, 511) ) > -1 )
          {
-test:
             if ( strncmp("st", shmem->buf, 2) )
             {
                /* not st, may be good */
@@ -2503,7 +2429,7 @@ test:
                    }
                    else
                       shmem->buf[i] = '\0';
-              }
+               }
             }
 
             ret = 0;
@@ -3010,7 +2936,7 @@ static int doAlignHead(char *name, int deviceHdl, int prot, int pass, int choice
       while (len > 0 )
       {
          toWrite = len > 1024 ? 1024 : len;
-         i = _Write(deviceHdl, (char*)printer_cmd + pos, toWrite,WRTIMEOUT);
+         i = _Write(deviceHdl, (uc*)printer_cmd + pos, toWrite,WRTIMEOUT);
          if ( i > 0 )
          {
             pos += i;
@@ -3108,7 +3034,7 @@ static int doAlignHeadColor(char *name, int deviceHdl, int prot, int pass, int c
       {
          exitD4(deviceHdl);
       }
-      i = _Write(deviceHdl, (char*)printer_cmd, bufpos, WRTIMEOUT);
+      i = _Write(deviceHdl, (uc*)printer_cmd, bufpos, WRTIMEOUT);
       return i;
    }
 
@@ -3136,7 +3062,7 @@ int writeD4Data(int deviceHdl, unsigned char *data, int len, int stop)
          if ( OpenChannel(deviceHdl, sockIdData, &sndSizeData, &rcvSizeData) > 0 )
          {
             ret = 0;
-         }        
+         }
       }
    }
    else
