@@ -39,6 +39,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <sys/types.h>
+#include <ctype.h>
 #include <sys/stat.h>
 #include <signal.h>
 #include <fcntl.h>
@@ -48,6 +49,7 @@
 #include <string.h>
 
 #include "d4lib.h"
+#include "rw.h"
 
 #ifdef MACOS
 #define USE_LIBUSB 1
@@ -65,7 +67,6 @@ extern int doRw;
 int debugD4     = 0;
 
 typedef void (*signalHandler_t)(int);
-static signalHandler_t sig;
 static int timeoutGot = 0;
 static int _readData(int fd, uc socketID, uc *buf, int len);
 
@@ -187,21 +188,6 @@ void printHexValues(char *dir, uc *buf, int len)
    fprintf(stderr,"\n");
 }
 
-/*******************************************************************/
-/* Function sigAlarm(int code)                                     */
-/*                                                                 */
-/* do nothing, avoid printing of undesired messages and/or         */
-/* other not desirable actions                                     */
-/*                                                                 */
-/*******************************************************************/
-
-static void sigAlarm(int code)
-{
-   timeoutGot = -1;
-   doRw = 0;
-}
-
-
 /*******************************************************************/
 /* Function printError()                                           */
 /*    print an error message on stderr                             */
@@ -283,7 +269,6 @@ static int writeCmd(int fd, unsigned char *cmd, int len)
 {
    int w;
    int i = 0;
-   struct  itimerval ti, oti;
    int cnt;
 # if PTIME
    struct timeval beg, end;
@@ -368,7 +353,6 @@ static int readAnswer(int fd, unsigned char *buf, int len)
    int rd    = 0;
    int total = 0;
    struct timeval beg, end;
-   struct itimerval ti, oti;
    long dt;
    int count = 0;
    /* wait a little bit before reading an answer */
@@ -380,7 +364,6 @@ static int readAnswer(int fd, unsigned char *buf, int len)
    /* set errno to 0 in order to get correct informations */
    /* in case of error                                    */
    errno = 0;
-
    gettimeofday(&beg, NULL);
 
    while ( total < len )
@@ -398,7 +381,7 @@ static int readAnswer(int fd, unsigned char *buf, int len)
          if ( dt > d4RdTimeout || errno )
          {
             if ( debugD4 )
-               fprintf(stderr,"Timeout 1 at readAnswer() rcv %d bytes %d ms\n",total, dt);
+               fprintf(stderr,"Timeout 1 at readAnswer() rcv %d bytes %d ms\n",(int)total, (int)dt);
             timeoutGot = 1;
             break;
          }
@@ -465,7 +448,6 @@ static int _readData(int fd, uc socketID, uc *buf, int len)
    int total = 0;
    struct timeval beg, end;
    long dt;
-   struct itimerval ti, oti;
 
    /* set errno to 0 in order to get correct informations */
    /* in case of error                                    */
@@ -486,7 +468,8 @@ static int _readData(int fd, uc socketID, uc *buf, int len)
       if ( dt > d4RdTimeout*3 )
       {
          if ( debugD4 )
-            fprintf(stderr,"Timeout at _readData(), dt = %d ms\n",dt);
+            fprintf(stderr,"Timeout at _readData(), dt = %d ms\n",(int)dt);
+
          return -1;
       }
    }
@@ -760,7 +743,7 @@ int OpenChannel(int fd, uc sockId, int *sndSz, int *rcvSz)
          return -1;
       }
    }
-   return 1;                 
+   return 1;
 }
 
 /*******************************************************************/
@@ -941,9 +924,10 @@ int writeData(int fd, uc socketID, uc *buf, int len, int eoj)
    uc  cmd[6];
    int wr = 0;
    int ret = 0;
-   struct  itimerval ti, oti;
+#if PTIME
    struct timeval beg, end;
    long dt;
+#endif
    static uc *buffer = NULL;
    static int bLen   = 0;
    int cnt=0;
@@ -951,7 +935,9 @@ int writeData(int fd, uc socketID, uc *buf, int len, int eoj)
    if ( debugD4 )
    {
       fprintf(stderr,"--- Send Data      ---\n");
+#if PTIME
       gettimeofday(&beg, NULL);
+#endif
    }
    len += 6;
    if ( len > bLen )
@@ -1049,6 +1035,7 @@ int writeData(int fd, uc socketID, uc *buf, int len, int eoj)
 int readData(int fd, uc socketID, uc *buf, int len)
 {
    int ret;
+
    /* give credit */
    if ( Credit(fd, socketID, 1) == 1 )
    {
@@ -1075,12 +1062,11 @@ int readData(int fd, uc socketID, uc *buf, int len)
 void clearSndBuf(int fd)
 {
    char             buf[256];
-   struct itimerval ti, oti;
 #ifndef USE_LIBUSB
-   while ( devRead(fd, buf, sizeof(buf),  d4RdTimeout) > 0 )
+   while ( devRead(fd, (unsigned char*)buf, sizeof(buf),  d4RdTimeout) > 0 )
       ;
 #else
-   while ( mRead(fd, buf, sizeof(buf) ) > 0 )
+   while ( mRead(fd, (unsigned char*)buf, sizeof(buf) ) > 0 )
       ;
 #endif
 }
@@ -1101,7 +1087,6 @@ int InitReply(int fd)
    cmd.head.command  = 0x80;
    cmd.head.result   = 0;   /* put the correct value here, 0,1,2 or 0x0b */
    cmd.revision      = 0x10;
-    
 }
 
 int ExitReply(int fd)
