@@ -113,7 +113,7 @@ char *drop_low[] =
 {
 
 "48 48 6 1",
-"  c red",
+"  c red m white",
 ". c #FFFFFF",
 "+ c #000000",
 "@ c #646464",
@@ -126,7 +126,7 @@ char *drop_warn[] =
 {
 
 "48 48 6 1",
-"  c orange",
+"  c orange m white",
 ". c #FFFFFF",
 "+ c #000000",
 "@ c #646464",
@@ -139,7 +139,7 @@ char *drop_ok[] =
 {
 
 "48 48 6 1",
-"  c green",
+"  c green m white",
 ". c #FFFFFF",
 "+ c #000000",
 "@ c #646464",
@@ -176,6 +176,9 @@ void chgIcon(int val)
 {
 #if XPM_OK
    static int oldVal = 0;
+
+   if ( topLevel2 == NULL )
+      return;
    if ( val == oldVal )
       return;
    switch (val)
@@ -390,15 +393,19 @@ static void createPixmaps(Widget w)
    Window         win = RootWindowOfScreen(XtScreen(w));
    XpmAttributes  attributes;
    Pixmap         shapemask;
-
+   int            ret;
+   
    memset(&attributes, 0, sizeof(attributes));
    attributes.valuemask = 0;
    
-   XpmCreatePixmapFromData(dsp, win, drop_low, &pmLow,  &shapemask, &attributes);
+   ret  = XpmCreatePixmapFromData(dsp, win, drop_low, &pmLow,  &shapemask, &attributes);
    attributes.valuemask = 0;
-   XpmCreatePixmapFromData(dsp, win, drop_warn, &pmWarn, &shapemask, &attributes);
+   ret |= XpmCreatePixmapFromData(dsp, win, drop_warn, &pmWarn, &shapemask, &attributes);
    attributes.valuemask = 0;
-   XpmCreatePixmapFromData(dsp, win, drop_ok, &pmHigh, &shapemask, &attributes);
+   ret |= XpmCreatePixmapFromData(dsp, win, drop_ok, &pmHigh, &shapemask, &attributes);
+   /* for SuSE 10.0 bug */
+   if ( ret != 0 )
+      pmLow = pmWarn = pmHigh = (Pixmap) 0;
 #endif   
 }
 
@@ -509,30 +516,59 @@ Widget createIconLayout(Widget top, XtAppContext app, char *mainResource, char *
    createPixmaps(topLevel2);
 
    /* create 3 push button according to the state we want */
-   low_PB = XtVaCreateWidget("low_PB",
-                             xmPushButtonWidgetClass,
-                             mainWindow2,
-                             XmNbackgroundPixmap, pmLow,
-                             XmNarmPixmap,        pmLow,
-                             XmNlabelType,        XmPIXMAP,
-                             NULL);
+   if ( pmLow != (Pixmap)0 )
+   {
+       low_PB = XtVaCreateWidget("low_PB",
+                                 xmPushButtonWidgetClass,
+                                 mainWindow2,
+                                 XmNbackgroundPixmap, pmLow,
+                                 XmNarmPixmap,        pmLow,
+                                 XmNlabelType,        XmPIXMAP,
+                                 NULL);
 
-   warn_PB = XtVaCreateWidget("warn_PB",
-                              xmPushButtonWidgetClass,
-                              mainWindow2,
-                              XmNbackgroundPixmap, pmWarn,
-                              XmNarmPixmap,        pmWarn,
-                              XmNlabelType,        XmPIXMAP,
-                              NULL);
+       warn_PB = XtVaCreateWidget("warn_PB",
+                                  xmPushButtonWidgetClass,
+                                  mainWindow2,
+                                  XmNbackgroundPixmap, pmWarn,
+                                  XmNarmPixmap,        pmWarn,
+                                  XmNlabelType,        XmPIXMAP,
+                                  NULL);
 
-   high_PB = XtVaCreateWidget("high_PB",
-                              xmPushButtonWidgetClass,
-                              mainWindow2,
-                              XmNbackgroundPixmap, pmHigh,
-                              XmNarmPixmap,        pmHigh,
-                              XmNlabelType,        XmPIXMAP,
-                              NULL);
+       high_PB = XtVaCreateWidget("high_PB",
+                                  xmPushButtonWidgetClass,
+                                  mainWindow2,
+                                  XmNbackgroundPixmap, pmHigh,
+                                  XmNarmPixmap,        pmHigh,
+                                  XmNlabelType,        XmPIXMAP,
+                                  NULL);
+   }
+   else /* and work around for buggy SuSE 10.0 */
+   {
+       XmString xms = XmStringCreateSimple(" ! ");
 
+       low_PB = XtVaCreateWidget("low_PB",
+                                 xmPushButtonWidgetClass,
+                                 mainWindow2,
+                                 XmNlabelString, xms,
+                                 NULL);
+       XtVaSetValues(low_PB, XtVaTypedArg, XmNbackground,XmRString,"red",8,NULL);
+
+       warn_PB = XtVaCreateWidget("warn_PB",
+                                  xmPushButtonWidgetClass,
+                                  mainWindow2,
+                                  XmNlabelString, xms,
+                                  NULL);
+       XtVaSetValues(warn_PB, XtVaTypedArg, XmNbackground,XmRString,"orange",8,NULL);
+
+       high_PB = XtVaCreateWidget("high_PB",
+                                  xmPushButtonWidgetClass,
+                                  mainWindow2,
+                                  XmNlabelString, xms,
+                                  NULL);
+       XtVaSetValues(high_PB, XtVaTypedArg, XmNbackground,XmRString,"green",8,NULL);
+       XmStringFree(xms);
+   }
+   
    /* This for Lesstif, the size must be set after the widget  */
    /* was created, motif openMotif allow to pass the values at */
    /* creation                                                 */
