@@ -13,9 +13,9 @@ configData_t defaultConfigData[] = {
    { "Stylus C20UX",          4, PROT_D4,          True,  False, False, True,  PROT_D4,          PROT_D4,          True,   3, 15,  2,  9, False, NULL },
    { "Stylus C40SX",          4, PROT_D4,          True,  False, False, True,  PROT_D4,          PROT_D4,          True,   3, 15,  2,  9, False, NULL },
    { "Stylus C40UX",          4, PROT_D4,          True,  False, False, True,  PROT_D4,          PROT_D4,          True,   3, 15,  2,  9, False, NULL },
+   { "Stylus C42",            4, PROT_D4,          True,  True,  True,  True,  PROT_D4,          PROT_D4,          True,  -3, 15,  0,  0, False, "/C42.align" },
    { "Stylus C42SX",          4, PROT_D4,          True,  True,  True,  True,  PROT_D4,          PROT_D4,          True,   3, 15,  2,  9, False, NULL },
    { "Stylus C42UX",          4, PROT_D4,          True,  True,  True,  True,  PROT_D4,          PROT_D4,          True,   3, 15,  2,  9, False, NULL },
-   { "Stylus C42",            4, PROT_D4,          True,  True,  True,  True,  PROT_D4,          PROT_D4,          True,  -3, 15,  0,  0, False, "/C42.align" },
    { "Stylus C50",            4, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
    { "Stylus C60",            4, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
    { "Stylus C62",            4, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
@@ -63,7 +63,6 @@ configData_t defaultConfigData[] = {
    { "Stylus Photo 780",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
    { "Stylus Photo 785",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
    { "Stylus Photo 790",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
-   { "Stylus Photo R800",     8, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   0,  0,  0,  0, False, NULL },
    { "Stylus Photo 810",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
    { "Stylus Photo 820",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, "Pattern820" },
    { "Stylus Photo 830",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, "Pattern820" },
@@ -73,6 +72,7 @@ configData_t defaultConfigData[] = {
    { "Stylus Photo 890",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, True,  NULL },
    { "Stylus Photo 895",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, True,  NULL },
    { "Stylus Photo 895EX",    6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, True,  NULL },
+   { "Stylus Photo 900",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
    { "Stylus Photo 900R",     7, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   0,  0,  0,  0, False, NULL },
    { "Stylus Photo 915",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
    { "Stylus Photo 925",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
@@ -85,6 +85,8 @@ configData_t defaultConfigData[] = {
    { "Stylus Photo 2000P",    6, PROT_D4,          True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   2, 15,  0,  0, False, NULL },
    { "Stylus Photo 2100",     7, PROT_D4,          True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   2, 15,  0,  0, False, NULL },
    { "Stylus Photo EX",       6, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
+   { "Stylus Photo R800",     8, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   0,  0,  0,  0, False, NULL },
+   { "Stylus Photo R2400",    8, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   0,  0,  0,  0, False, NULL },
    { "Stylus Pro 5000",       6, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
    { "Stylus Pro 5500",       6, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
    { "Stylus Pro 7000",       6, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
