@@ -322,7 +322,6 @@ static int readDataFile(FILE *fp)
 int _mStrCmp(char *s, char *t)
 {
    int ret = 0;
-   int a, b;
    while ( !ret && *s )
    {
       if ( isdigit(*s) && isdigit(*t) )
@@ -350,8 +349,6 @@ int _mStrCmp(char *s, char *t)
 
 static int cmpName(const void *P1, const void *P2)
 {
-   int ret;
-   char *s, *t;
    configData_t *p1 = (configData_t *)P1;
    configData_t *p2 = (configData_t *)P2;
 
