@@ -37,54 +37,6 @@
 static char *msgOut     = NULL;
 static char **resources = NULL;
 
-static struct termios oldTerm;
-static struct termios newTerm;
-static int termInittialized = 0;
-
-#if 0
-/*******************************************************************/
-/* Function initTerm                                               */
-/*                                                                 */
-/* set terminal mode to raw and no echo so we can do simple editing*/
-/*                                                                 */
-/*******************************************************************/
-
-void initTerm()
-{
-   if ( !termInittialized )
-   {
-      tcgetattr(fileno(stdin), &oldTerm);
-      tcgetattr(fileno(stdin), &newTerm);
-      newTerm.c_iflag &= ~(IGNBRK|BRKINT|PARMRK|ISTRIP|INLCR|IGNCR|ICRNL|IXON);
-      newTerm.c_oflag &= ~OPOST;
-      newTerm.c_lflag &= ~(ECHO|ECHONL|ICANON|ISIG|IEXTEN);
-      newTerm.c_cflag &= ~(CSIZE|PARENB);
-      newTerm.c_cflag |= CS8;
-#ifdef VMIN
-      newTerm.c_cc[VMIN] = 1;
-#endif     
-   }
-   tcsetattr(fileno(stdin),TCSANOW,&newTerm);
-   termInittialized = 1;
-}
-
-/*******************************************************************/
-/* Function resetTerm                                              */
-/*                                                                 */
-/* reset terminal mode to old value                                */
-/*                                                                 */
-/*******************************************************************/
-
-void resetTerm()
-{
-   if ( termInittialized )
-      tcsetattr(fileno(stdin),TCSANOW,&oldTerm);
-}
-#else
-# define initTerm()
-# define resetTerm()
-#endif
-
 /*******************************************************************/
 /* Function mfgets()                                               */
 /*                                                                 */
@@ -502,7 +454,6 @@ int askYn(char *lang, char *yn)
    char *answers = searchString(lang, yn);
    char *s;
 
-   initTerm();
    if ( answers && *answers )
    {
       fgets(in, sizeof(in),stdin);
@@ -510,11 +461,9 @@ int askYn(char *lang, char *yn)
       while ( *s && isspace(*s) ) s++;
       if ( toupper(*s) == toupper(*answers) )
       {
-         resetTerm();
          return 1;
       }
    }
-   resetTerm();
    return 0;
 }
 
@@ -529,14 +478,13 @@ int askNo(int first, int last)
 {
    int number = 0;
    char  in[20];
-   initTerm();
+
    do
    {
       printf("%d ... %d : ", first, last);
       fgets(in,sizeof(in), stdin);
       number = atoi(in);
    } while ( !(number >= first && number <= last) );
-   resetTerm();
 
    return number;
 }
