@@ -582,6 +582,15 @@ char *fallbackResources[] = {
    ".De.dyellow:              Dunkelgelb",
    ".De.gloss:                Glanzoptimierer",
    ".De.grey:                 Grau",
+#if 0
+/*
+   ! Photo R2400 die Franzsiche Texte beinhalten korreckterweise
+   ! grau und hell grau. Hellschwarz und Hellhellschwarz ist ein
+   ! Unsinn !
+*/
+#endif
+   ".De.llblack:              Grau",
+   ".De.Lblack:               Hellgrau",
 
 
    ".De.printerState:         Druckertatus",
@@ -809,6 +818,15 @@ char *fallbackResources[] = {
    ".De8.dyellow:              Dunkelgelb",
    ".De8.gloss:                Glanzoptimierer",
    ".De8.grey:                 Grau",
+#if 0
+/*
+   ! Photo R2400 die Französiche Texte beinhalten korreckterweise
+   ! grau und hell grau. Hellschwarz und Hellhellschwarz ist ein
+   ! Unsinn !
+*/
+#endif
+   ".De8.llblack:              Grau",
+   ".De8.Lblack:               Hellgrau",
 
 
    ".De8.printerState:         Druckertatus",
@@ -1044,6 +1062,8 @@ char *fallbackResources[] = {
    ".dyellow:              Dark yellow",
    ".gloss:                Gloss optimizer",
    ".grey:                 Grey",
+   ".llblack:              Light light black",
+   ".Lblack:               Light black",
 
    ".printerState:         printer state",
    ".unknown:              unknown",
@@ -1284,6 +1304,8 @@ char *fallbackResources[] = {
    ".dyellow:              Dark yellow",
    ".gloss:                Gloss optimizer",
    ".grey:                 Grey",
+   ".llblack:              Light light black",
+   ".Lblack:               Light black",
 
    ".printerState:         printer state",
    ".unknown:              unknown",
@@ -1528,6 +1550,8 @@ char *fallbackResources[] = {
    ".Fr.dyellow:              jaune fonc",
    ".Fr.gloss:                optimisation du glaage",
    ".Fr.grey:                 gris",
+   ".Fr.llblack:              gris",
+   ".Fr.Lblack:               gris clair",
 
    ".Fr.printerState:         status imprimante",
    ".Fr.unknown:              inconnu",
@@ -1771,6 +1795,8 @@ char *fallbackResources[] = {
    ".Fr8.dyellow:              jaune foncé",
    ".Fr8.gloss:                optimisation du glaçage",
    ".Fr8.grey:                 gris",
+   ".Fr8.llblack:              gris",
+   ".Fr8.Lblack:               gris clair",
 
    ".Fr8.printerState:         status imprimante",
    ".Fr8.unknown:              inconnu",
