@@ -35,6 +35,7 @@
 #endif
 
 #include "mtink.h"
+#include "access.h"
 
 #include "rcfile.h"
 #include "rdRes.h"
@@ -43,7 +44,6 @@
 #include "version.h"
 
 #include "d4lib.h"
-//#include "d4libh.h"
 
 #include "rdPrtDesc.h"
 #define defaultConfigData configData
@@ -99,6 +99,7 @@ int setConfig(char *lang);
 
 int (*ynFunc)(char*,char*);
 
+extern int inFromFile;
 
 /*******************************************************************/
 /* Function sigKill(int code)                                      */
@@ -122,7 +123,7 @@ static void sigKill(int code)
 
 void setPrinterStateLabel(int state)
 {
-#if 0
+#if 0 /* not now */
    switch(state)
    {
       case 0:  printerState = appResourceRec.error;    break;
@@ -207,6 +208,11 @@ void parseArgs(int argc, char **argv, char *lang)
 
    while ( argc )
    {
+      if ( strncmp("-F", argv[0], 2) == 0)
+      {
+         inFromFile = 1;
+      }
+      else
       if ( strncmp("-h", argv[0], 2) == 0 ||
                 strncmp("--h", argv[0], 3) == 0 )
       {
@@ -476,6 +482,19 @@ int main(int argc, char **argv)
    signal(SIGQUIT, sigKill);
    signal(SIGSEGV, sigKill);
 #ifndef MACOS
+   if ( device )
+   {
+      /* Check access rights to the device */
+      if ( fileAccess(device,R_OK|W_OK) == -1 )
+      {
+         /* we have not the permission to write
+          * and read
+          */
+          fprintText(stderr,"%s\n", lang, "noAccess");
+          exit_CB(1);         
+      }
+   }
+
    if ( (model == NULL || doIdent ) && ! d4Printer )
    {
       /* try to detect the printer model */
@@ -993,6 +1012,7 @@ int decodeStatus(unsigned char *buf, int len, char *lang)
                case 4: plc = percent(buf+i);
                   if ( colorModel == MODEL_KCMycm  ||
                        colorModel == MODEL_KCMycmY ||
+                       colorModel == MODEL_KCMycmGg ||
                        colorModel == MODEL_KCMycmk    )
                       printText("\t%-20s:",lang,"lcyan");
                   else
@@ -1002,6 +1022,7 @@ int decodeStatus(unsigned char *buf, int len, char *lang)
                case 5: plm = percent(buf+i);
                   if ( colorModel == MODEL_KCMycm ||
                        colorModel == MODEL_KCMycmY ||
+                       colorModel == MODEL_KCMycmGg ||
                        colorModel == MODEL_KCMycmk    )
                       printText("\t%-20s:",lang,"lmagenta");
                   else
@@ -1017,51 +1038,27 @@ int decodeStatus(unsigned char *buf, int len, char *lang)
                       printText("\t%-20s:",lang,"lblack");
                   else if ( colorModel == MODEL_KCMyRBX )
                       printText("\t%-20s:",lang,"gloss");
+                  else if ( colorModel == MODEL_KCMycmGg )
+                      printText("\t%-20s:",lang,"Lblack");
                   printf(" %2d %%\n",plb);
                break;
                case 7: pb  = percent(buf+i);
                   if ( colorModel == MODEL_KCMyRBkX )
+                  {
                      printText("\t%-20s:",lang,"gloss");
-                   printf(" %2d %%\n",pb);
+                      printf(" %2d %%\n",pb);
+                  }
+                  else if ( colorModel == MODEL_KCMycmGg )
+                  {
+                     printText("\t%-20s:",lang,"llblack");
+                      printf(" %2d %%\n",pb);
+                  }
                break;
             }
             colIdx++;
             i += 2;
          }
       }
-#endif
-#if 0
-      else if ( strncmp(&buf[i], "WR:", 3 ) == 0 )
-      {
-         infOk = 1;
-         i += 3;
-         colIdx = 0;
-         while ( i < len && colIdx < 6 && buf[i] != ';' )
-         {
-            switch( buf[i+1] )
-            {
-               case '0':
-               case '1':
-               case '2':
-               case '3':
-               case '4':
-               case '5':
-                  s = color[buf[i+1]-'0'];
-                  /* color[buf[i+1] (color) is LOW */
-                  break;
-               default: s = code;
-                  code[0] = buf[i];
-                  code[1] = buf[i+1];
-                  code[2] = 0;
-            }
-            if ( buf[i+2] == ';' )
-            {
-               i += 3;
-               break;
-            }
-            i += 3;
-         }
-      }
 #endif
       else
       {
