@@ -463,16 +463,7 @@ static int getId(int dn)
          buf[rd] = 0;
          decodePrinterType(buf,rd, dn );
       }
-#if 0 /* this will not work for all printers */
-      rd = usbRead(dn, buf, 511);
-      if ( rd > 0 )
-      {
-         buf[rd] = 0;
-         decodePrinterType(buf,rd, dn);
-      }
-#else
       state = callPrg(GET_ID, devices[dn].devname, PROT_D4, 0, 0, &iBuf, NULL );
-#endif
    }
 
    return 0;
