@@ -10,7 +10,7 @@ from pyinkHTTPHandler import rdRes
 from pyinkHTTPHandler import readConf
 
 # set these two variable according to your needs
-prefix='/usr'
+prefix='/usr/local'
 pyinkHTTPHandler.gl.confDir=prefix+'/lib/mtink'
 pyinkHTTPHandler.gl.tmpDir=prefix+'/lib/pyink/tmp'
 workDir=prefix+'/lib/pyink'
