@@ -1,4 +1,4 @@
 #!/bin/sh
 
-prefix=/usr
+prefix=/usr/local
 $prefix/lib/pyink/pyink.py
