@@ -40,11 +40,11 @@
 #include <string.h>
 #include <sys/ipc.h>
 #include <sys/shm.h>
-#ifdef MACOS
-#include "fakepoll.h"
-#else
+//#ifdef MACOS
+//#include "fakepoll.h"
+//#else
 #include <sys/poll.h>
-#endif
+//#endif
 #include <dirent.h>
 #include <sys/ioctl.h>
 
