@@ -5,12 +5,14 @@
 # Set SEARCH to the line which will precede the new entry
 # \ must be duplicated
 
-SEARCH='Ronny Budzinske\\n\\'
+
+SEARCH='   http://xwgui.automatix.de\\n\\'
 
 # Set APPEND to the line which will is to be added
 # \ must be duplicated
 
-APPEND='Nicola Fabiano\\n\\   ivololeribar@yahoo.it\\n\\'
+APPEND='Rainer Krienke\\n\\\n   krienke@uni-koblenz.de\\n\\'
+
 for f in Mtink.??
 do
    awk '{
