@@ -25,6 +25,9 @@
  
 #include <stdio.h>
 #include <ctype.h>
+#include <string.h>
+#include <unistd.h>
+#include <stdlib.h>
 
 void printHead()
 {
